@@ -5,9 +5,9 @@ use strict;
 use warnings;
 # use Carp;
 
-our $VERSION = '0.04_01'; # 2003-04-14 (since 2003-03-26)
+our $VERSION = '0.04_02'; # 2003-04-14 (since 2003-03-26)
 
-use utf8;
+# use utf8;
 use Encode;
 
 require Exporter;
@@ -130,7 +130,7 @@ sub _cut {
 
 =item fold_ex($i)
 
-This object method folds the string within the specified length of $i calculated as full-width characters. In addition to that, this method estimates the forbidden rule for the specific marks. It is said that this method is rather formal than the fold() as the Japanese text.
+This object method folds up the string within the specified length of $i calculated as full-width characters. In addition to that, this method estimates the forbidden rule for the specific marks. It is said that this method is rather formal than the fold() as the Japanese text.
 
 The forbidden rule is: 1) the termination marks like Ten "," and Maru ".", 2) closing marks -- brace or parenthesis or bracket -- like ")", "}", "]", ">" and etc., 3) repeat marks, those should not be at the top of a line. If it would be occured, these marks should be moved to the place at the end of the previous line.
 
@@ -142,9 +142,8 @@ Note that these marks are all full-width Japanese characters.
 
 =cut
 
-my $Forbidden = '’”、。〃々〉》」』】〕〟ゝゞヽヾ），．］｝';
-utf8::upgrade($Forbidden);
-# my $Forbidden = '\x{2019}\x{201D}\x{3001}-\x{3003}\x{3005}\x{3009}\x{300B}\x{300D}\x{300F}\x{3011}\x{3015}\x{301F}\x{309D}\x{309E}\x{30FD}\x{30FE}\x{FF09}\x{FF0C}\x{FF0E}\x{FF3D}\x{FF5D}';
+# my $Forbidden = '’”、。〃々〉》」』】〕〟ゝゞヽヾ），．］｝';
+my $Forbidden = '\x{2019}\x{201D}\x{3001}-\x{3003}\x{3005}\x{3009}\x{300B}\x{300D}\x{300F}\x{3011}\x{3015}\x{301F}\x{309D}\x{309E}\x{30FD}\x{30FE}\x{FF09}\x{FF0C}\x{FF0E}\x{FF3D}\x{FF5D}';
 
 sub fold_ex {
 	my($self, $length) = @_;
